==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1ScopeSelectorFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ScopeSelectorFluent<A extends V1ScopeSelectorFluent<A>> extends Fluent<A>{


    public A addToMatchExpressions(int index,V1ScopedResourceSelectorRequirement item);
    public A setToMatchExpressions(int index,V1ScopedResourceSelectorRequirement item);
    public A addToMatchExpressions(V1ScopedResourceSelectorRequirement... items);
    public A addAllToMatchExpressions(Collection<V1ScopedResourceSelectorRequirement> items);
    public A removeFromMatchExpressions(V1ScopedResourceSelectorRequirement... items);
    public A removeAllFromMatchExpressions(Collection<V1ScopedResourceSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ScopedResourceSelectorRequirement> getMatchExpressions();
    public List<V1ScopedResourceSelectorRequirement> buildMatchExpressions();
    public V1ScopedResourceSelectorRequirement buildMatchExpression(int index);
    public V1ScopedResourceSelectorRequirement buildFirstMatchExpression();
    public V1ScopedResourceSelectorRequirement buildLastMatchExpression();
    public V1ScopedResourceSelectorRequirement buildMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1ScopedResourceSelectorRequirementBuilder> predicate);
    public A withMatchExpressions(List<V1ScopedResourceSelectorRequirement> matchExpressions);
    public A withMatchExpressions(V1ScopedResourceSelectorRequirement... matchExpressions);
    public Boolean hasMatchExpressions();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> addNewMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(V1ScopedResourceSelectorRequirement item);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(int index,V1ScopedResourceSelectorRequirement item);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editMatchExpression(int index);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editFirstMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editLastMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1ScopedResourceSelectorRequirementBuilder> predicate);

    public interface MatchExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ScopedResourceSelectorRequirementFluent<V1ScopeSelectorFluent.MatchExpressionsNested<N>>{

        
    public N and();    public N endMatchExpression();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ScopeSelectorFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ScopeSelectorFluent<A extends V1ScopeSelectorFluent<A>> extends Fluent<A>{


    public A addToMatchExpressions(int index,V1ScopedResourceSelectorRequirement item);
    public A setToMatchExpressions(int index,V1ScopedResourceSelectorRequirement item);
    public A addToMatchExpressions(V1ScopedResourceSelectorRequirement... items);
    public A addAllToMatchExpressions(Collection<V1ScopedResourceSelectorRequirement> items);
    public A removeFromMatchExpressions(V1ScopedResourceSelectorRequirement... items);
    public A removeAllFromMatchExpressions(Collection<V1ScopedResourceSelectorRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ScopedResourceSelectorRequirement> getMatchExpressions();
    public List<V1ScopedResourceSelectorRequirement> buildMatchExpressions();
    public V1ScopedResourceSelectorRequirement buildMatchExpression(int index);
    public V1ScopedResourceSelectorRequirement buildFirstMatchExpression();
    public V1ScopedResourceSelectorRequirement buildLastMatchExpression();
    public V1ScopedResourceSelectorRequirement buildMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1ScopedResourceSelectorRequirementBuilder> predicate);
    public Boolean hasMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1ScopedResourceSelectorRequirementBuilder> predicate);
    public A withMatchExpressions(List<V1ScopedResourceSelectorRequirement> matchExpressions);
    public A withMatchExpressions(V1ScopedResourceSelectorRequirement... matchExpressions);
    public Boolean hasMatchExpressions();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> addNewMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> addNewMatchExpressionLike(V1ScopedResourceSelectorRequirement item);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> setNewMatchExpressionLike(int index,V1ScopedResourceSelectorRequirement item);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editMatchExpression(int index);
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editFirstMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editLastMatchExpression();
    public V1ScopeSelectorFluent.MatchExpressionsNested<A> editMatchingMatchExpression(io.kubernetes.client.fluent.Predicate<V1ScopedResourceSelectorRequirementBuilder> predicate);

    public interface MatchExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ScopedResourceSelectorRequirementFluent<V1ScopeSelectorFluent.MatchExpressionsNested<N>>{

        
    public N and();    public N endMatchExpression();
}


}
